@@ -7,9 +7,15 @@
 import re
 import ctypes
 import inspect
+from .utils import get_version
 try:
     import numba as nb
-    import numba.typing.ctypes_utils
+    if get_version('numba') >= (0, 49):
+        from numba.core import typing, datamodel
+        from numba.core.imputils import lower_cast
+    else:
+        from numba import typing, datamodel
+        from numba.targets.imputils import lower_cast
     nb_NA_message = None
 except ImportError as msg:
     nb = None
@@ -707,7 +713,7 @@ class Type(tuple):
         n = _numba_imap.get(t)
         if n is not None:
             return cls.fromstring(n, target_info)
-        if isinstance(t, nb.typing.templates.Signature):
+        if isinstance(t, typing.templates.Signature):
             atypes = (cls.fromnumba(a, target_info)
                       for a in t.args)
             rtype = cls.fromnumba(t.return_type, target_info)
@@ -1099,27 +1105,27 @@ def _demangle(s):
 
 
 if nb is not None:
-    class Boolean1(numba.types.Boolean):
+    class Boolean1(nb.types.Boolean):
 
         def can_convert_from(self, typingctx, other):
-            return isinstance(other, numba.types.Boolean)
+            return isinstance(other, nb.types.Boolean)
 
-    @numba.datamodel.register_default(Boolean1)
-    class Boolean1Model(numba.datamodel.models.BooleanModel):
+    @datamodel.register_default(Boolean1)
+    class Boolean1Model(datamodel.models.BooleanModel):
 
         def get_data_type(self):
             return self._bit_type
 
-    class Boolean8(numba.types.Boolean):
+    class Boolean8(nb.types.Boolean):
 
         def can_convert_to(self, typingctx, other):
-            return isinstance(other, numba.types.Boolean)
+            return isinstance(other, nb.types.Boolean)
 
         def can_convert_from(self, typingctx, other):
-            return isinstance(other, numba.types.Boolean)
+            return isinstance(other, nb.types.Boolean)
 
-    @numba.datamodel.register_default(Boolean8)
-    class Boolean8Model(numba.datamodel.models.BooleanModel):
+    @datamodel.register_default(Boolean8)
+    class Boolean8Model(datamodel.models.BooleanModel):
 
         def get_value_type(self):
             return self._byte_type
@@ -1127,13 +1133,13 @@ if nb is not None:
     boolean1 = Boolean1('boolean1')
     boolean8 = Boolean8('boolean8')
 
-    @numba.targets.imputils.lower_cast(Boolean1, numba.types.Boolean)
-    @numba.targets.imputils.lower_cast(Boolean8, numba.types.Boolean)
+    @lower_cast(Boolean1, nb.types.Boolean)
+    @lower_cast(Boolean8, nb.types.Boolean)
     def literal_booleanN_to_boolean(context, builder, fromty, toty, val):
         return builder.icmp_signed('!=', val, val.type(0))
 
-    @numba.targets.imputils.lower_cast(numba.types.Boolean, Boolean1)
-    @numba.targets.imputils.lower_cast(numba.types.Boolean, Boolean8)
+    @lower_cast(nb.types.Boolean, Boolean1)
+    @lower_cast(nb.types.Boolean, Boolean8)
     def literal_boolean_to_booleanN(context, builder, fromty, toty, val):
         llty = context.get_value_type(toty)
         return builder.zext(val, llty)
@@ -1145,13 +1151,13 @@ def make_numba_struct(name, members, _cache={}):
     t = _cache.get(name)
     if t is None:
         def model__init__(self, dmm, fe_type):
-            numba.datamodel.StructModel.__init__(self, dmm, fe_type, members)
+            datamodel.StructModel.__init__(self, dmm, fe_type, members)
         struct_model = type(name+'Model',
-                            (numba.datamodel.StructModel,),
+                            (datamodel.StructModel,),
                             dict(__init__=model__init__))
-        struct_type = type(name+'Type', (numba.types.Type,),
+        struct_type = type(name+'Type', (nb.types.Type,),
                            dict(members=[t for n, t in members]))
-        numba.datamodel.registry.register_default(struct_type)(struct_model)
+        datamodel.registry.register_default(struct_type)(struct_model)
         _cache[name] = t = struct_type(name)
     return t
 
